.. image:: https://img.shields.io/pypi/v/dvg-pyqt-controls
    :target: https://pypi.org/project/dvg-pyqt-controls
.. image:: https://img.shields.io/pypi/pyversions/dvg-pyqt-controls
    :target: https://pypi.org/project/dvg-pyqt-controls
.. image:: https://requires.io/github/Dennis-van-Gils/python-dvg-pyqt-controls/requirements.svg?branch=master
    :target: https://requires.io/github/Dennis-van-Gils/python-dvg-pyqt-controls/requirements/?branch=master
    :alt: Requirements Status
.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black
.. image:: https://img.shields.io/badge/License-MIT-purple.svg
    :target: https://github.com/Dennis-van-Gils/python-dvg-pyqt-controls/blob/master/LICENSE.txt

DvG_PyQt_controls
=================
*Mishmash of PyQt5 stylesheets and custom controls that I personally use
in many of my projects.*

- Github: https://github.com/Dennis-van-Gils/python-dvg-pyqt-controls
- PyPI: https://pypi.org/project/dvg-pyqt-controls

Installation::

    pip install dvg-pyqt-controls
    
.. image:: https://raw.githubusercontent.com/Dennis-van-Gils/python-dvg-pyqt-controls/master/demos/demo_pyqt_controls.png
